@@ -30,6 +30,10 @@ module OmniAuth
         { raw_info: raw_info }
       end
 
+      def callback_url
+        full_host + callback_path
+      end
+
       protected
 
       def raw_info
